@@ -744,4 +744,16 @@ class LoopN(object):
         """
         """
         pass
-        return None
\ No newline at end of file
+        return None
+
+def get_prefix_of_loop(item: LoopN):
+    if not(isinstance(item, LoopN)):
+        return ""
+    if item.ITEM_CLASS is ItemN:
+        if len(item.items) > 0:
+            prefix = item.items[0].PREFIX
+        else:
+            return ""
+    else:
+        prefix = item.ITEM_CLASS.PREFIX
+    return prefix
\ No newline at end of file
