@@ -606,7 +606,17 @@ class GlobalN(object):
                     linear_constraints.append([(coeff_1, name_1), (coeff_2, name_2)])
         if len(linear_constraints) > 0:
             dict_out["linear_constraints"] = linear_constraints
-
+        try:
+            expression = self.punishment.function
+            d_marked = {}
+            for rcif_name, dict_name in zip(variable_names, dict_names):
+                rcif_name_mark = rcif_name[:-1]+ ((rcif_name[-1][0]+"_mark", rcif_name[-1][1]),)
+                mark = self.get_variable_by_name(rcif_name_mark)
+                if mark != "":
+                    d_marked[mark] = dict_name
+            dict_out["punishment_function"] = (expression, d_marked)
+        except:
+            pass
         return dict_out
 
 
@@ -681,6 +691,15 @@ def transfer_cif_names_to_dict_names(variable_names):
         elif name == "y":
             name = "resolution_parameters"
             index = (4, )
+        elif name == "fract_x":
+            name = "atom_fract_xyz"
+            index = (0, index)
+        elif name == "fract_y":
+            name = "atom_fract_xyz"
+            index = (1, index)
+        elif name == "fract_z":
+            name = "atom_fract_xyz"
+            index = (2, index)
         if isinstance(index, int):
             index = (index, )
         dict_names.append((data_block.lower(), name.lower(), index))
