@@ -77,7 +77,7 @@ class PdBackgroundL(LoopN):
         super(PdBackgroundL, self).__init__()
         self.__dict__["items"] = form_items_by_dictionary(self.ITEM_CLASS, kwargs)
         self.__dict__["loop_name"] = loop_name
-   
+
     def interpolate_by_points(self, tth):
         l_ttheta = self.ttheta
         l_intensity = self.intensity
@@ -93,10 +93,10 @@ class PdBackgroundL(LoopN):
         ttheta = numpy.array(pd_meas.ttheta, dtype=float)
         if pd_meas.items[0].is_attribute("intensity_plus"):
             intensity = (
-                numpy.array(pd_meas.intensity_plus, dtype=float) + 
+                numpy.array(pd_meas.intensity_plus, dtype=float) +
                 numpy.array(pd_meas.intensity_minus, dtype=float))
             intensity_sigma = numpy.sqrt(
-                numpy.square(numpy.array(pd_meas.intensity_plus_sigma, dtype=float)) + 
+                numpy.square(numpy.array(pd_meas.intensity_plus_sigma, dtype=float)) +
                 numpy.square(numpy.array(pd_meas.intensity_minus_sigma, dtype=float)))
         else:
             intensity = numpy.array(pd_meas.intensity, dtype=float)
@@ -116,16 +116,23 @@ class PdBackgroundL(LoopN):
 
         # n_points = int((ttheta.max()-ttheta.min())/step_ttheta + 2)
         # ttheta_bkgr = numpy.linspace(ttheta.min(), ttheta.max(), n_points, endpoint=True)
-        # 
+        #
         # flags = numpy.abs(ttheta[na, :]-ttheta_bkgr[:, na])<step_ttheta
-        # 
+        #
         # int_bkrg = numpy.array([numpy.nanmin(intensity_bkg[flag], axis=0) for flag in flags], dtype=float)
         # int_bkrg = numpy.round(int_bkrg, decimals=5)
         self.numpy_ttheta = ttheta
         self.numpy_intensity = intensity_bkg
         self.items = []
         self.numpy_to_items()
-        return 
+        return
+
+    def get_dictionary(self):
+        res = {}
+        res["background_ttheta"] = numpy.array(self.ttheta, dtype=float)*numpy.pi/180.
+        res["background_intensity"] = numpy.array(self.intensity, dtype=float)
+        res["flags_background_intensity"] = numpy.array(self.intensity_refinement, dtype=bool)
+        return res
 
 def estimate_background(y_exp, step_n: int = 10):
     n_points = numpy.arange(1, step_n+1)
@@ -137,7 +144,7 @@ def estimate_background(y_exp, step_n: int = 10):
     # y_bkg_es[flag] = y_exp[flag]
     # y_bkg_es[numpy.logical_not(flag)] = y_aver+2*(y_aver-y_min)
     y_bkg_es = numpy.copy(y_exp)
-    
+
     n_total = y_bkg_es.size
     for iii in range(100):
         y_bkg_new = numpy.zeros_like(y_bkg_es)
@@ -159,13 +166,13 @@ def estimate_background(y_exp, step_n: int = 10):
             y_right = y_bkg_es[ind_right]
 
             y_bkg_new[i_point] = (y_left+y_right).sum()/(2*step_n)
-            
+
 
         if iii != 99:
             flag = y_bkg_new > y_bkg_es
             y_bkg_new[flag] = y_bkg_es[flag]
         y_bkg_es = y_bkg_new
-    y_bkg = y_bkg_es  
+    y_bkg = y_bkg_es
     return y_bkg
 
 
