@@ -164,7 +164,7 @@ class PdProcL(LoopN):
             chi_sq_points = numpy.nansum(numpy.square((np_sum - np_sum_mod)/np_ssum)[np_notexcl])/numpy.sum(np_notexcl) 
             chi_sq_diff_points = numpy.nansum(numpy.square((np_diff - np_diff_mod)/np_ssum))/np_diff_mod.size
 
-            ax_1.set_title(f"Unpolarized ($\chi^2/n = ${chi_sq_points:.2f}) and polarized ($\chi^2/n = ${chi_sq_diff_points:.2f}) signals")
+            ax_1.set_title(f"Unpolarized ($\\chi^2/n = ${chi_sq_points:.2f}) and polarized ($\\chi^2/n = ${chi_sq_diff_points:.2f}) signals")
             ax_1.fill_between(np_tth, (np_sum-np_ssum), (np_sum+np_ssum), where=np_notexcl, color="k", alpha=0.4, label="experiment")
             if numpy.any(np_excl):
                 ax_1.fill_between(np_tth, (np_sum-np_ssum), (np_sum+np_ssum), where=np_excl, color="r", alpha=0.5, label="excluded")
@@ -223,7 +223,7 @@ class PdProcL(LoopN):
             np_sum_mod = np_up_mod + np_down_mod + np_bkg
 
             chi_sq_points = numpy.nansum(numpy.square((np_sum - np_sum_mod)/np_ssum)[np_notexcl])/numpy.sum(np_notexcl) 
-            ax_1.set_title(f"Unpolarized signal $\chi^2/n = ${chi_sq_points:.2f}")
+            ax_1.set_title(f"Unpolarized signal $\\chi^2/n = ${chi_sq_points:.2f}")
 
             ax_1.fill_between(np_tth, (np_sum-np_ssum), (np_sum+np_ssum), where=np_notexcl, color="k", alpha=0.4, label="experiment")
             ax_1.fill_between(np_tth, (np_sum-np_ssum), (np_sum+np_ssum), where=np_excl, color="r", alpha=0.5, label="excluded")
@@ -278,7 +278,7 @@ class PdProcL(LoopN):
         np_sdiff = numpy.sqrt(numpy.square(np_sup)+numpy.square(np_sdown))
 
         chi_sq_points = numpy.nansum(numpy.square((np_diff - np_diff_mod)/np_sdiff))/(np_sdiff.size) 
-        ax.set_title(f"Polarized signal $\chi^2/n = ${chi_sq_points:.2f}")
+        ax.set_title(f"Polarized signal $\\chi^2/n = ${chi_sq_points:.2f}")
 
         ax.plot([np_tth.min(), np_tth.max()], [0., 0.], "b:")
         ax.fill_between(np_tth, (np_diff-np_sdiff), (np_diff+np_sdiff), color="k", alpha=0.4, label="experiment")        
