@@ -526,9 +526,11 @@ class SpaceGroup(ItemN):
 
         xyz_s_un, unique_inverse = numpy.unique(xyz_s, return_inverse=True,
                                                 axis=1)
+        # Output for unique_inverse in version of numpy 2.0.0 and 1.23.5 is different. 
+        # This line is to unified two versions
+        unique_inverse = unique_inverse.flatten()
         x_s, y_s, z_s = xyz_s_un[0, :], xyz_s_un[1, :], xyz_s_un[2, :]
         ind = (numpy.where((x-x_s)**2+(y-y_s)**2+(z-z_s)**2 < 0.00001))[0][0]
-
         flag = unique_inverse == ind
         o_11, o_12, o_13 = e_11[flag], e_12[flag], e_13[flag]
         o_21, o_22, o_23 = e_21[flag], e_22[flag], e_23[flag]
