@@ -11,7 +11,10 @@ from cryspy.A_functions_base.debye_waller_factor import calc_param_iso_aniso_by_
 from cryspy.A_functions_base.matrix_operations import calc_m1_m2_inv_m1, calc_m_v
 from cryspy.A_functions_base.magnetic_form_factor import get_j0_j2_parameters
 from cryspy.A_functions_base.unit_cell import calc_eq_ccs_by_unit_cell_parameters, calc_m_m_by_unit_cell_parameters, calc_reciprocal_by_unit_cell_parameters
-from cryspy.A_functions_base.structure_factor import calc_f_nucl_by_dictionary, calc_sft_ccs_by_dictionary, calc_f_m_perp_by_sft, calc_bulk_susceptibility_by_dictionary
+from cryspy.A_functions_base.structure_factor import \
+    calc_f_nucl_by_dictionary, calc_sft_ccs_by_dictionary, \
+    calc_f_m_perp_by_sft, calc_bulk_susceptibility_by_dictionary, \
+    calc_f_m_perp_ordered_by_dictionary
 from cryspy.A_functions_base.symmetry_elements import calc_full_mag_elems, calc_symm_flags, define_bravais_type_by_symm_elems
 from cryspy.A_functions_base.symmetry_constraints import calc_sc_beta, calc_sc_fract_sc_b, calc_sc_chi, calc_sc_chi_full
 
@@ -48,9 +51,6 @@ from cryspy.C_item_loop_classes.cl_2_space_group_symop_magn_operation import \
 from cryspy.C_item_loop_classes.cl_2_space_group import SpaceGroup
 
 
-
-
-
 from cryspy.D_functions_item_loop.function_1_report_magnetization_ellipsoid \
     import magnetization_ellipsoid_by_u_ij, report_main_axes_of_magnetization_ellipsoids
 
@@ -212,6 +212,23 @@ class Crystal(DataN):
         return f_nucl
 
 
+    def calc_f_mag(self, index_hkl, magnetic_field_ccs: numpy.ndarray = numpy.array([0.,0.,0.], dtype=float)):
+        flag_use_precalculated_data = False
+        dict_crystal = self.get_dictionary()
+        dict_crystal_keys = dict_crystal.keys() 
+        dict_in_out = {"index_hkl": index_hkl, "flag_only_orbital": False}
+        sft_ccs = calc_sft_ccs_by_dictionary(dict_crystal, dict_in_out, flag_use_precalculated_data=flag_use_precalculated_data)[0]
+        f_mag = calc_m_v(sft_ccs, magnetic_field_ccs, flag_m=False, flag_v=False)[0]
+        if "atom_ordered_index" in dict_crystal_keys:
+            calc_f_m_perp_ordered_by_dictionary(
+                dict_crystal, dict_in_out, flag_use_precalculated_data=flag_use_precalculated_data)
+            if "f_m_o" in dict_in_out.keys():
+                f_m_o = dict_in_out["f_m_o"]
+                f_mag += f_m_o
+        return f_mag
+
+
+
     def calc_refln(self, index_hkl,
                    flag_internal: bool = True):
         """
@@ -702,8 +719,8 @@ class Crystal(DataN):
                         scattering_amplitude = calc_scattering_amplitude_tabulated(type_symbol, table_sthovl)[0]
                     except KeyError:
                         flag_atom_scattering_amplitude = False
-                        break
-                l_table_atom_scattering_amplitude.append(scattering_amplitude)
+                if flag_atom_scattering_amplitude:
+                    l_table_atom_scattering_amplitude.append(scattering_amplitude)
 
                 type_atom = get_atom_name_ion_charge_shell(type_symbol)[0]
                 try:
