@@ -26,22 +26,22 @@ where `file_name` is the address of the file.
     
 Features
   - Analysis of the polarized neutron scattering on crystals;
-  - Diffraction data refinement for single crystals or powder;
+  - Diffraction data refinement for single crystals or powder by RhoChi class;
   - MEM for reconstruction of magnetization density by MEM class;
   - Powder refinement of magnetic space groups.
   - TOF neutron data analysis
 
-For more information please see the site: https://ikibalin.github.io/cryspy/
+For more information please see the site: https://www.cryspy.fr/
 """
 __author__ = 'Iurii KIBALIN'
-__copyright__   = "Copyright 2023, "
+__copyright__   = "Copyright 2024, "
 __credits__ = ["Iurii KIBALIN", "Andrew SAZONOV", "Arsen GOUKASSOV"]
 __license__ = "GPL"
-__version__ = "0.7.2"
+__version__ = "0.8.0"
 __maintainer__ = "Iurii KIBALIN"
-__email__ = "yurikibalin@outlook.com"
+__email__ = "iurii.kibalin@cea.fr"
 __status__ = "Development"
-__date__ = "08.03.2023"
+__date__ = "24.09.2025"
 name = "cryspy"
 
 
@@ -85,7 +85,7 @@ from cryspy.A_functions_base.function_1_strings import value_error_mark_to_strin
     transform_fraction_with_label_to_string, transform_digits_to_string,\
     transform_r_b_to_string
 
-from cryspy.A_functions_base.function_1_tof import tof_Jorgensen, \
+from cryspy.A_functions_base.powder_diffraction_tof import tof_Jorgensen, \
     tof_Jorgensen_VonDreele
 
 
@@ -127,6 +127,9 @@ from cryspy.A_functions_base.function_3_mcif import \
 from cryspy.A_functions_base.function_4_flip_ratio import \
     calc_f_plus_sq, calc_f_minus_sq, calc_flip_ratio
 
+from cryspy.B_parent_classes.cl_2_loop import \
+ get_prefix_of_loop
+
 from cryspy.D_functions_item_loop.function_1_section_from_density_point \
     import calc_section_from_density_point
 
@@ -147,7 +150,8 @@ from cryspy.H_functions_global.function_1_cryspy_objects import \
     L_GLOBAL_CLASS, L_DATA_CLASS, L_LOOP_CLASS, L_ITEM_CLASS, load_packages, \
     add_package, packages, delete_package, L_FUNCTION_ADD
 
-from cryspy.H_functions_global.powder_experiments import report_powder_experiments
+from cryspy.H_functions_global.powder_experiments import \
+    report_powder_experiments
 
 from cryspy.procedure_rhochi.rhochi import rhochi_rietveld_refinement, \
     rhochi_rietveld_refinement_with_parameters, \
@@ -160,9 +164,6 @@ from cryspy.procedure_mempy.mempy import  mempy_magnetization_density_reconstruc
     mempy_cycle_with_parameters
 
 
-from cryspy.H_functions_global.simulations import simulation_pd
-
-
 
 
 def repr_function(function, flag_long: bool = False):
@@ -272,7 +273,7 @@ L_FUNCTION = [
     mempy_spin_density_reconstruction,
     mempy_reconstruction_with_parameters,
     mempy_cycle_with_parameters,
-    simulation_pd]
+    get_prefix_of_loop]
 
 def functions(s_name: str = "", flag_long: bool = False):
     l_function = L_FUNCTION + L_FUNCTION_ADD
