@@ -341,11 +341,12 @@ def mempy_reconstruction_by_dictionary(dict_crystal, dict_mem_parameters, l_dict
                     flag_cos_2theta=False,
                     flag_wavelength=False)
 
+            axis_z = matrix_u[6:9] 
             iint_plus, iint_minus, dder_plus, dder_minus = calc_iint(
-                beam_polarization, flipper_efficiency, f_nucl, f_m_perp, matrix_u, func_extinction = func_extinction,
+                beam_polarization, flipper_efficiency, f_nucl, f_m_perp, axis_z, func_extinction = func_extinction,
                 flag_beam_polarization = False, flag_flipper_efficiency = False,
                 flag_f_nucl = False, flag_f_m_perp = True,
-                dict_in_out = dict_in_out, flag_use_precalculated_data = flag_use_precalculated_data)
+                dict_in_out = dict_in_out)
 
             diffrn_dict_in_out["flip_ratio"] = iint_plus/iint_minus
 
