@@ -5,7 +5,8 @@ from cryspy.A_functions_base.unit_cell import \
     calc_sthovl_by_unit_cell_parameters
 
 from cryspy.A_functions_base.structure_factor import \
-    calc_f_nucl_by_dictionary, calc_sft_ccs_by_dictionary, calc_f_m_perp_by_sft
+    calc_f_nucl_by_dictionary, calc_sft_ccs_by_dictionary, calc_f_m_perp_by_sft, \
+    calc_f_m_perp_ordered_by_dictionary
 
 from cryspy.A_functions_base.extinction import \
     calc_extinction_sphere
@@ -58,6 +59,7 @@ def calc_chi_sq_for_diffrn_by_dictionary(
         dict_in_out_keys = dict_in_out.keys()
 
     dict_diffrn_keys = dict_diffrn.keys()
+    dict_crystal_keys = dict_crystal.keys()
 
     unit_cell_parameters = dict_crystal["unit_cell_parameters"]
     index_hkl = dict_diffrn["index_hkl"]
@@ -70,20 +72,28 @@ def calc_chi_sq_for_diffrn_by_dictionary(
     flag_magnetic_field=False
 
     matrix_u = dict_diffrn["matrix_u"]
-    beam_polarization = dict_diffrn["beam_polarization"]
-    flags_beam_polarization = dict_diffrn["flags_beam_polarization"]
-    flipper_efficiency = dict_diffrn["flipper_efficiency"]
-    flags_flipper_efficiency = dict_diffrn["flags_flipper_efficiency"]
     wavelength = dict_diffrn["wavelength"]
     flags_wavelength = dict_diffrn["flags_wavelength"]
-    flip_ratio_es = dict_diffrn["flip_ratio_es"]
-    flip_ratio_excluded = dict_diffrn["flip_ratio_excluded"]
+    flip_ratio_excluded = dict_diffrn["flip_ratio_excluded"] # it also work for intensity
+
+    flag_unpolarized, flag_asymmetry = False, False
+    if "flip_ratio_es" in dict_diffrn_keys:
+        flip_ratio_es = dict_diffrn["flip_ratio_es"]
+        beam_polarization = dict_diffrn["beam_polarization"]
+        flags_beam_polarization = dict_diffrn["flags_beam_polarization"]
+        flipper_efficiency = dict_diffrn["flipper_efficiency"]
+        flags_flipper_efficiency = dict_diffrn["flags_flipper_efficiency"]
+        if "flag_asymmetry" in dict_diffrn_keys:
+            flag_asymmetry = dict_diffrn["flag_asymmetry"]
+    elif "intensity_es" in dict_diffrn_keys:
+        intensity_es = dict_diffrn["intensity_es"]
+        phase_scale = dict_diffrn["phase_scale"]
+        flags_phase_scale = dict_diffrn["flags_phase_scale"]
+        beam_polarization = 1.
+        flipper_efficiency = 1.
+        flag_unpolarized = True
+        flags_beam_polarization, flags_flipper_efficiency = False, False
 
-    if "flag_asymmetry" in dict_diffrn_keys:
-        flag_asymmetry = dict_diffrn["flag_asymmetry"]
-    else:
-        flag_asymmetry = False
-    
     if "c_lambda2" in dict_diffrn_keys:
         c_lambda2 = dict_diffrn["c_lambda2"]
         flags_c_lambda2 = dict_diffrn["flags_c_lambda2"]
@@ -92,7 +102,7 @@ def calc_chi_sq_for_diffrn_by_dictionary(
         c_lambda2 = None
         flags_c_lambda2 = False
         index_2hkl = None
-
+    dict_in_out["index_hkl"] = dict_diffrn["index_hkl"]
     flag_eq_ccs = flag_unit_cell_parameters
     if (flag_use_precalculated_data and not(flag_eq_ccs) and ("eq_ccs" in dict_in_out_keys)):
         eq_ccs = dict_in_out["eq_ccs"]
@@ -156,15 +166,26 @@ def calc_chi_sq_for_diffrn_by_dictionary(
     sft_ccs, dder_sft_ccs = calc_sft_ccs_by_dictionary(dict_crystal, dict_in_out_crystal_hkl, flag_use_precalculated_data=flag_use_precalculated_data)
     flag_sft_ccs = len(dder_sft_ccs.keys()) > 0
 
+    flag_ordered = False
+    flag_f_m_perp_o_ccs = False
+    if "atom_ordered_index" in dict_crystal_keys:
+        f_m_perp_o_ccs, dder_f_m_perp_o_ccs = calc_f_m_perp_ordered_by_dictionary(
+            dict_crystal, dict_in_out, flag_use_precalculated_data=flag_use_precalculated_data)
+        flag_f_m_perp_o_ccs =  dict_crystal["flags_atom_ordered_moment_crystalaxis_xyz"].any()
+        flag_ordered = True
+
     flag_mag_atom_susceptibility = "mag_atom_susceptibility" in dder_sft_ccs.keys()
 
-    flag_f_m_perp = flag_sft_ccs or flag_magnetic_field or flag_eq_ccs
+    flag_f_m_perp = flag_sft_ccs or flag_magnetic_field or flag_eq_ccs or flag_f_m_perp_o_ccs
     
     if (flag_use_precalculated_data and not(flag_f_m_perp) and "f_m_perp" in dict_in_out_keys):
         f_m_perp = dict_in_out["f_m_perp"]
     else:
         f_m_perp, dder_f_m_perp = calc_f_m_perp_by_sft(
                 sft_ccs, magnetic_field, eq_ccs, flag_sft_ccs=flag_sft_ccs, flag_magnetic_field=flag_magnetic_field, flag_eq_ccs=flag_eq_ccs)
+        if flag_ordered:
+            f_m_perp += f_m_perp_o_ccs
+            dder_f_m_perp.update(dder_f_m_perp_o_ccs)
         if flag_dict:
             dict_in_out["f_m_perp"] = f_m_perp
 
@@ -209,15 +230,16 @@ def calc_chi_sq_for_diffrn_by_dictionary(
         iint_plus = dict_in_out["iint_plus"]
         iint_minus = dict_in_out["iint_minus"]
     else:
+        axis_z = matrix_u[6:9]
         iint_plus, iint_minus, dder_plus, dder_minus = calc_intensities_by_structure_factors(
-            beam_polarization, flipper_efficiency, f_nucl, f_m_perp, matrix_u,
+            beam_polarization, flipper_efficiency, f_nucl, f_m_perp, axis_z,
             func_extinction=func_extinction,
             c_lambda2=c_lambda2, f_nucl_2hkl=f_nucl_2hkl, f_m_perp_2hkl=f_m_perp_2hkl,
             flag_beam_polarization=flags_beam_polarization, flag_flipper_efficiency=flags_flipper_efficiency,
             flag_f_nucl=flag_f_nucl, flag_f_m_perp=flag_f_m_perp,
             flag_c_lambda2=flags_c_lambda2,
             flag_f_nucl_2hkl=flag_f_nucl_2hkl, flag_f_m_perp_2hkl=flag_f_m_perp_2hkl,
-            dict_in_out=dict_in_out, flag_use_precalculated_data=flag_use_precalculated_data)
+            dict_in_out=dict_in_out)
         if flag_dict:
             dict_in_out["iint_plus"] = iint_plus
             dict_in_out["iint_minus"] = iint_minus
@@ -231,6 +253,14 @@ def calc_chi_sq_for_diffrn_by_dictionary(
             iint_plus, iint_minus, c_lambda2=None, iint_2hkl=None,
             flag_iint_plus=True, flag_iint_minus=True, 
             flag_c_lambda2=False, flag_iint_2hkl=False)
+    elif flag_unpolarized:
+        model_exp = (iint_plus + iint_minus)*phase_scale
+        dict_in_out["intensity_calc"] = model_exp
+        exp_value = intensity_es
+        dder_model_exp = {
+            "iint_plus": numpy.ones_like(iint_plus)*phase_scale,
+            "iint_minus": numpy.ones_like(iint_minus)*phase_scale,
+            }
     else:
         model_exp, dder_model_exp = calc_flip_ratio_by_iint(
             iint_plus, iint_minus, c_lambda2=None, iint_2hkl=None,
@@ -275,7 +305,6 @@ def calc_chi_sq_for_diffrn_by_dictionary(
         dder_plus_crystal["mag_atom_susceptibility"] = numpy.swapaxes(dder_plus_mas, 0, 1)
         dder_minus_crystal["mag_atom_susceptibility"] = numpy.swapaxes(dder_minus_mas, 0, 1)
         
-    
     dder_plus_diffrn, dder_minus_diffrn = {}, {}
     if flags_beam_polarization:
         dder_plus_diffrn["beam_polarization"] = dder_plus["beam_polarization"][:, na]
@@ -319,6 +348,9 @@ def calc_chi_sq_for_diffrn_by_dictionary(
             elif name in dder_minus_diffrn_keys:
                 dder_minus_p = dder_minus_diffrn[name][:, flags]
                 dder_plus_p = numpy.zeros_like(dder_minus_p)
+            elif name == "phase_scale":#FIXME
+                dder_plus_p = numpy.zeros(shape=(index_true.size, 1), dtype=float)
+                dder_minus_p = numpy.zeros(shape=(index_true.size, 1), dtype=float)
             else:
                 raise AttributeError("It should not be like this.")
             parameter_name = [(diffrn_type_name, ) + way + (tuple(ind_1d[ind,:]), ) for ind in range(ind_1d.shape[0])]
